#[non_exhaustive]pub enum Decoded {
Nothing,
GlobalPalette(Box<[u8]>),
BackgroundColor(u8),
HeaderEnd,
BlockStart(Block),
SubBlock {
ext: AnyExtension,
is_last: bool,
},
FrameMetadata(FrameDataType),
BytesDecoded(NonZeroUsize),
LzwDataCopied(usize),
DataEnd,
}Expand description
Indicates whether a certain object has been decoded
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Nothing
Decoded nothing.
GlobalPalette(Box<[u8]>)
Global palette.
BackgroundColor(u8)
Index of the background color in the global palette.
HeaderEnd
Palette and optional Application extension have been parsed,
reached frame data.
BlockStart(Block)
The start of a block.
BlockStart(Block::Trailer) is the very last decode event
SubBlock
Decoded a sub-block.
Call last_ext_sub_block() to get the sub-block data. It won’t be available after this event.
Fields
ext: AnyExtensionAn ext label of 0 is used when the sub block does not belong to an extension.
FrameMetadata(FrameDataType)
Decoded all information of the next frame, except the image data.
The returned frame does not contain any owned image data.
Call current_frame_mut() to access the frame info.
BytesDecoded(NonZeroUsize)
Decoded some data of the current frame. Size is in bytes, always > 0
LzwDataCopied(usize)
Copied (or consumed and discarded) compressed data of the current frame. In bytes.
DataEnd
No more data available the current frame.